glue\_genes.glue\_genomics\_data.multires\_data.ReducedResolutionData
=====================================================================

.. currentmodule:: glue_genes.glue_genomics_data.multires_data

.. autoclass:: ReducedResolutionData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ReducedResolutionData.__init__
      ~ReducedResolutionData.add_component
      ~ReducedResolutionData.add_component_link
      ~ReducedResolutionData.add_subset
      ~ReducedResolutionData.broadcast
      ~ReducedResolutionData.component_ids
      ~ReducedResolutionData.compute_fixed_resolution_buffer
      ~ReducedResolutionData.compute_histogram
      ~ReducedResolutionData.compute_statistic
      ~ReducedResolutionData.convert_full_to_reduced_cid
      ~ReducedResolutionData.convert_reduced_to_full_cid
      ~ReducedResolutionData.dtype
      ~ReducedResolutionData.find_component_id
      ~ReducedResolutionData.get_component
      ~ReducedResolutionData.get_data
      ~ReducedResolutionData.get_kind
      ~ReducedResolutionData.get_mask
      ~ReducedResolutionData.get_object
      ~ReducedResolutionData.get_selection_definition
      ~ReducedResolutionData.get_subset_object
      ~ReducedResolutionData.join_on_key
      ~ReducedResolutionData.new_subset
      ~ReducedResolutionData.register_to_hub
      ~ReducedResolutionData.remove_component
      ~ReducedResolutionData.reorder_components
      ~ReducedResolutionData.to_dataframe
      ~ReducedResolutionData.update_components
      ~ReducedResolutionData.update_id
      ~ReducedResolutionData.update_values_from_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ReducedResolutionData.components
      ~ReducedResolutionData.coordinate_components
      ~ReducedResolutionData.coordinate_links
      ~ReducedResolutionData.coords
      ~ReducedResolutionData.data
      ~ReducedResolutionData.derived_components
      ~ReducedResolutionData.derived_links
      ~ReducedResolutionData.externally_derivable_components
      ~ReducedResolutionData.label
      ~ReducedResolutionData.links
      ~ReducedResolutionData.main_components
      ~ReducedResolutionData.ndim
      ~ReducedResolutionData.pixel_aligned_data
      ~ReducedResolutionData.pixel_component_ids
      ~ReducedResolutionData.primary_components
      ~ReducedResolutionData.shape
      ~ReducedResolutionData.size
      ~ReducedResolutionData.subsets
      ~ReducedResolutionData.visible_components
      ~ReducedResolutionData.world_component_ids
   
   